/* PACK.SURNAME.rexx  version 1.1 */
/* This macro can be run from the CLI, SHELL or WorkBench and */
/* sorts and packs a text-based citation database into a form */
/* suitable for sorting using the ARP 1.3 SORT command.  The macro */
/* writes a text file with each field of the citation/record */
/* concatenated on a single line. */

/* open the normal citation text file (database) for import */
/* NOTE: change the disk/drive designations below to suit your setup */
in_text = getfile(,,'ram:',,'Select unsorted citation file');
if (in_text = '') then exit;
if (open(importfile,in_text,'R') ~= 1) then;
  do;
    say 'I could not open the file ' || in_text || ' for importing.';
    exit;
  end;

/* open the text file for export of surname, packed citations */
out_text = getfile(,,'ram:',,'Select packed export filename');
if (out_text = '') then exit;
if (open(exportfile,out_text,'W') ~= 1) then;
  do;
    say 'I could not open the file ' || out_text || ' for exporting.';
    exit;
  end;


/* get the first record */
do loop = 1 to 5;
  field.loop = readln(importfile);
end;


/* export the packed record/citations in the database */
do while (~EOF(importfile));
  packed_citation = (field.1 || '|' || field.2 || '|' || field.3 || '|' || field.4 || '|' || field.5);
  say ' ';
  say packed_citation;
  foo = writeln(exportfile,packed_citation);


/* get the next record */
  do loop = 1 to 5;
    field.loop = readln(importfile);
  end;
end;

/* exit macro */
say ' ';
say 'Packed, surname-first citations in file ' || out_text;
exit;
