/* UNPACK.YEAR.rexx  version 1.1 */
/* This macro can be run from the CLI, SHELL or WorkBench and */
/* acts on a sorted, packed, text-based citation database from */
/* which you wish to export standard citations.  The macro */
/* writes a text file with each field of the citation/record */
/* on a separate line. */

/* open the packed citation text file (database) for import */
/* NOTE: change the disk/drive designations below to suit your setup */
in_text = getfile(,,'ram:',,'Select packed citation file');
if (in_text = '') then exit;
if (open(importfile,in_text,'R') ~= 1) then;
  do;
    say 'I could not open the file ' || in_text || ' for importing.';
    exit;
  end;

/* open the text file for export */
out_text = getfile(,,'ram:',,'Select sorted export file name');
if (out_text = '') then exit;
if (open(exportfile,out_text,'W') ~= 1) then;
  do;
    say 'I could not open the file ' || out_text || ' for exporting.';
    exit;
  end;


/* get the first record */
pack_cite = readln(importfile);


/* export the sorted, unpacked record/citations in the database */
do while (~EOF(importfile));
  parse var pack_cite year '|' authors '|' title '|' source '|' journal;
  say authors;
  say year;
  say title;
  say source;
  say journal;
  foo = writeln(exportfile,authors);
  foo = writeln(exportfile,year);
  foo = writeln(exportfile,title);
  foo = writeln(exportfile,source);
  foo = writeln(exportfile,journal);


/* get the next record */
  pack_cite = readln(importfile);
end;

/* exit macro */
say ' ';
say 'Unpacked, year-sorted citations in file ' || out_text;
exit;
